//
//  AppDelegate.m
//  testComplications
//
//  Created by James Bamford on 14/06/2016.
//  Copyright © 2016 JB. All rights reserved.
//

#import "AppDelegate.h"

@interface AppDelegate ()

@property (nonatomic, readwrite) BOOL watchConnectivityIsActive;

@end

@implementation AppDelegate

#define DbgLog(fmt, ...)    NSLog((@"%s:%d - " fmt), __PRETTY_FUNCTION__, __LINE__, ##__VA_ARGS__)

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
  DbgLog(@"");
  [self setupWatchConnectivitySession];
  
  // Override point for customization after application launch.
  return YES;
}

- (void)applicationWillResignActive:(UIApplication *)application {
  // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
  // Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
}

- (void)applicationDidEnterBackground:(UIApplication *)application {
  // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later.
  // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
}

- (void)applicationWillEnterForeground:(UIApplication *)application {
  // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
}

- (void)applicationDidBecomeActive:(UIApplication *)application {
  // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
}

- (void)applicationWillTerminate:(UIApplication *)application {
  // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
}

- (void)setupWatchConnectivitySession
{
  DbgLog(@"");
  if ([WCSession isSupported])
  {
    DbgLog(@"WCSession isSupported, activating");
    
    WCSession* session = [WCSession defaultSession];
    
    session.delegate = self;
    [session activateSession];
    
    [self checkWatchConnectivityState:session];
  }
}

- (void)checkWatchConnectivityState:(WCSession*)session
{
  DbgLog(@"");
  BOOL doneIt=NO;
  
  if (session.paired)
  {
    DbgLog(@"session is paired");
    
    if (session.watchAppInstalled)
    {
      DbgLog(@"watchApp is installed");
      
      DbgLog(@"setting watchConnectivityIsActive to YES!");
      
      BOOL watchConnectivityWasActive=self.watchConnectivityIsActive;
      
      self.watchConnectivityIsActive = YES;
      doneIt = YES;
      
      if (!watchConnectivityWasActive)
      {
        DbgLog(@"we are newly becoming active with watch connectivity");
      }
    }
    else
    {
      DbgLog(@"watchApp is NOT installed");
    }
  }
  else
  {
    DbgLog(@"session is NOT paired");
  }
  
  if (!doneIt)
  {
    DbgLog(@"setting watchConnectivityIsActive to NO!");
    self.watchConnectivityIsActive = NO;
  }
}

#pragma mark - WCSessionDelegate

- (void)sessionWatchStateDidChange:(WCSession *)session
{
  DbgLog(@"");
  
  [self checkWatchConnectivityState:session];
}

- (void)updateWatchConnectivityComplicationUserInfo:(NSDictionary*)complicationUserInfo
{
  DbgLog(@"watchConnectivityIsActive=%d", self.watchConnectivityIsActive);
  
  if (self.watchConnectivityIsActive)
  {
    WCSession *session = [WCSession defaultSession];
    DbgLog(@"watchConnectivityIsActive so sending on userInfo session.complicationEnabled=%d", session.complicationEnabled);
    
    if (session.complicationEnabled && complicationUserInfo)
    {
      DbgLog(@"session.complicationEnabled so transfering current complication user info");
      [session transferCurrentComplicationUserInfo:complicationUserInfo];
    }
  }
  else
  {
    DbgLog(@"watchConnectivityIsActive is NO so NOT sending on contextDictionary");
  }
}
@end
